from setuptools import setup

setup(name='hs-stats',
      version='0.1',
      description='Gaussian distributions',
      packages=['hs-stats'],
      author='Hério Sousa',
      author_email='heriosousa@hotmail.com',
      zip_safe=False)
